##  Defining Conditional Attribute
Conditional attributes can be defined in meta model configuration by users with admin rights. To define a conditional attribute, do the following:
  1. In the administration area, under Basic Settings, choose Meta Model Configuration.
  2. Select the fact sheet type for which you want to add a conditional attribute.
  3. Select Conditional Attribute tab at the top.
  4. Click +Add New Condition.
  5. Select the activator field from the drop-down menu under the prompt “When filling out this field”. Fields which are under hidden sections, subsection and the Unused Fields and Relations are also available to choose as activator.
  6. Select the activating value under the prompt “If the value selected is”.
  7. Select the attribute or multiple attributes to be activated under “Then display these attributes”, and click the check mark.
![Defining Conditional Attributes](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio2749d7be7a441014964e9cab953cdd82_LowRes.gif)
Defining Conditional Attributes
